plottags
========

|downloads| |license|

A command line utility for viewing the trend of commit tagging within a repository over time.

Currently supports GIT and Mercurial repositories.

Fun fact, plottags was the 60115th package registered with PyPI.


Installation
------------

::

    pip install plottags

Usage
-----

From within a repo...

::
    
    $ plottags

Example Results:
----------------

This plot is from the CPython project.

|cpython|


.. |cpython| image:: https://raw.githubusercontent.com/logston/plottags/master/cpython.png
    :alt: Resutls from plotting the tags from the CPython project.

.. |downloads| image:: https://pypip.in/download/plottags/badge.svg?period=month
    :target: https://pypi.python.org/pypi/plottags
    :alt: Downloads

.. |license| image:: https://pypip.in/license/plottags/badge.svg
    :target: https://pypi.python.org/pypi/plottags/
    :alt: License

